# deepbio
![](https://img.shields.io/badge/deepbio-Backbone-519dd9.svg)
![](https://img.shields.io/badge/date-August_2019-green.svg)
## Overview
##### The repository is for rrc ppi dti

* stamp 1
    + version 1.0
    + time: August 2019